==> cdk_2.3.orig.tar.gz: cdk-cdk-2.3/tool/charges/src/test/java/org/openscience/cdk/charges/AtomTypeChargesTest.java <==
/* Copyright (C) 2008  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@list.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.charges;

import org.junit.Assert;
import org.junit.Ignore;
import org.junit.Test;
import org.openscience.cdk.CDKTestCase;

/**
 * @cdk.module  test-charges
 * @author      egonw
 * @cdk.created 2008-01-04
 */
public class AtomTypeChargesTest extends CDKTestCase {

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for pOC atom types.
     */
    @Ignore
    @Test
    public void testCharges_pOC() throws Exception {
        Assert.fail("Not tested yet");
    }

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for pOP atom types.
     */
    @Ignore
    @Test
    public void testCharges_pOP() throws Exception {
        Assert.fail("Not tested yet");
    }

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for pOS atom types.
     */
    @Ignore
    @Test
    public void testCharges_pOS() throws Exception {
        Assert.fail("Not tested yet");
    }

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for p_p atom types.
     */
    @Ignore
    @Test
    public void testCharges_p_p() throws Exception {
        Assert.fail("Not tested yet");
    }

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for p_n atom types.
     */
    @Ignore
    @Test
    public void testCharges_p_n() throws Exception {
        Assert.fail("Not tested yet");
    }

}

==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/tool/charges/src/test/java/org/openscience/cdk/charges/AtomTypeChargesTest.java <==
/* Copyright (C) 2008  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@list.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.charges;

import org.junit.Assert;
import org.junit.Ignore;
import org.junit.Test;
import org.openscience.cdk.test.CDKTestCase;

/**
 * @cdk.module  test-charges
 * @author      egonw
 * @cdk.created 2008-01-04
 */
public class AtomTypeChargesTest extends CDKTestCase {

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for pOC atom types.
     */
    @Ignore
    @Test
    public void testCharges_pOC() throws Exception {
        Assert.fail("Not tested yet");
    }

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for pOP atom types.
     */
    @Ignore
    @Test
    public void testCharges_pOP() throws Exception {
        Assert.fail("Not tested yet");
    }

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for pOS atom types.
     */
    @Ignore
    @Test
    public void testCharges_pOS() throws Exception {
        Assert.fail("Not tested yet");
    }

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for p_p atom types.
     */
    @Ignore
    @Test
    public void testCharges_p_p() throws Exception {
        Assert.fail("Not tested yet");
    }

    /**
     * Tests the initial assignment of partial charges of
     * atom types matching the HOSE code for p_n atom types.
     */
    @Ignore
    @Test
    public void testCharges_p_n() throws Exception {
        Assert.fail("Not tested yet");
    }

}
